summaryrefslogtreecommitdiffstats
path: root/make/config/nativewindow/x11-CustomCCode.c
diff options
context:
space:
mode:
authorMichael Bien <[email protected]>2010-03-28 20:25:31 +0200
committerMichael Bien <[email protected]>2010-03-28 20:25:31 +0200
commitbe452bbfbb101292350cc6a483471a0e98ac937b (patch)
tree6877831b84b87d48ba928e3ac55ecf8a5c18b0ab /make/config/nativewindow/x11-CustomCCode.c
parent9e8ba29142d83d5749fc9650715019fef3539b1d (diff)
final large refactoring to move to com.jogamp.*.
Diffstat (limited to 'make/config/nativewindow/x11-CustomCCode.c')
-rwxr-xr-xmake/config/nativewindow/x11-CustomCCode.c26
1 files changed, 13 insertions, 13 deletions
diff --git a/make/config/nativewindow/x11-CustomCCode.c b/make/config/nativewindow/x11-CustomCCode.c
index c1f66fee1..8eded9aa2 100755
--- a/make/config/nativewindow/x11-CustomCCode.c
+++ b/make/config/nativewindow/x11-CustomCCode.c
@@ -48,22 +48,22 @@ Bool XF86VidModeSetGammaRamp(
/* Need to expose DefaultScreen and RootWindow macros to Java */
JNIEXPORT jlong JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_DefaultScreen(JNIEnv *env, jclass _unused, jlong display) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_DefaultScreen(JNIEnv *env, jclass _unused, jlong display) {
return DefaultScreen((Display*) (intptr_t) display);
}
JNIEXPORT jlong JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_DefaultVisualID(JNIEnv *env, jclass _unused, jlong display, jint screen) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_DefaultVisualID(JNIEnv *env, jclass _unused, jlong display, jint screen) {
return (jlong) XVisualIDFromVisual( DefaultVisual( (Display*) (intptr_t) display, screen ) );
}
JNIEXPORT jlong JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_RootWindow(JNIEnv *env, jclass _unused, jlong display, jint screen) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_RootWindow(JNIEnv *env, jclass _unused, jlong display, jint screen) {
return RootWindow((Display*) (intptr_t) display, screen);
}
JNIEXPORT jlong JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_dlopen(JNIEnv *env, jclass _unused, jstring name) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_dlopen(JNIEnv *env, jclass _unused, jstring name) {
const jbyte* chars;
void* res;
chars = (*env)->GetStringUTFChars(env, name, NULL);
@@ -73,7 +73,7 @@ Java_com_sun_nativewindow_impl_x11_X11Lib_dlopen(JNIEnv *env, jclass _unused, js
}
JNIEXPORT jlong JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_dlsym(JNIEnv *env, jclass _unused, jstring name) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_dlsym(JNIEnv *env, jclass _unused, jstring name) {
const jbyte* chars;
void* res;
chars = (*env)->GetStringUTFChars(env, name, NULL);
@@ -85,7 +85,7 @@ Java_com_sun_nativewindow_impl_x11_X11Lib_dlsym(JNIEnv *env, jclass _unused, jst
/* Need to pull this in as we don't have a stub header for it */
extern Bool XineramaEnabled(Display* display);
-static const char * clazzNameInternalBufferUtil = "com/sun/nativewindow/impl/InternalBufferUtil";
+static const char * clazzNameInternalBufferUtil = "com/jogamp/nativewindow/impl/InternalBufferUtil";
static const char * clazzNameInternalBufferUtilStaticCstrName = "copyByteBuffer";
static const char * clazzNameInternalBufferUtilStaticCstrSignature = "(Ljava/nio/ByteBuffer;)Ljava/nio/ByteBuffer;";
static const char * clazzNameByteBuffer = "java/nio/ByteBuffer";
@@ -100,29 +100,29 @@ static void _initClazzAccess(JNIEnv *env) {
c = (*env)->FindClass(env, clazzNameInternalBufferUtil);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_nativewindow_impl_x11_X11Lib: can't find %s\n", clazzNameInternalBufferUtil);
+ fprintf(stderr, "FatalError: Java_com_jogamp_nativewindow_impl_x11_X11Lib: can't find %s\n", clazzNameInternalBufferUtil);
(*env)->FatalError(env, clazzNameInternalBufferUtil);
}
clazzInternalBufferUtil = (jclass)(*env)->NewGlobalRef(env, c);
if(NULL==clazzInternalBufferUtil) {
- fprintf(stderr, "FatalError: Java_com_sun_nativewindow_impl_x11_X11Lib: can't use %s\n", clazzNameInternalBufferUtil);
+ fprintf(stderr, "FatalError: Java_com_jogamp_nativewindow_impl_x11_X11Lib: can't use %s\n", clazzNameInternalBufferUtil);
(*env)->FatalError(env, clazzNameInternalBufferUtil);
}
c = (*env)->FindClass(env, clazzNameByteBuffer);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_nativewindow_impl_x11_X11Lib: can't find %s\n", clazzNameByteBuffer);
+ fprintf(stderr, "FatalError: Java_com_jogamp_nativewindow_impl_x11_X11Lib: can't find %s\n", clazzNameByteBuffer);
(*env)->FatalError(env, clazzNameByteBuffer);
}
clazzByteBuffer = (jclass)(*env)->NewGlobalRef(env, c);
if(NULL==c) {
- fprintf(stderr, "FatalError: Java_com_sun_nativewindow_impl_x11_X11Lib: can't use %s\n", clazzNameByteBuffer);
+ fprintf(stderr, "FatalError: Java_com_jogamp_nativewindow_impl_x11_X11Lib: can't use %s\n", clazzNameByteBuffer);
(*env)->FatalError(env, clazzNameByteBuffer);
}
cstrInternalBufferUtil = (*env)->GetStaticMethodID(env, clazzInternalBufferUtil,
clazzNameInternalBufferUtilStaticCstrName, clazzNameInternalBufferUtilStaticCstrSignature);
if(NULL==cstrInternalBufferUtil) {
- fprintf(stderr, "FatalError: Java_com_sun_nativewindow_impl_x11_X11Lib:: can't create %s.%s %s\n",
+ fprintf(stderr, "FatalError: Java_com_jogamp_nativewindow_impl_x11_X11Lib:: can't create %s.%s %s\n",
clazzNameInternalBufferUtil,
clazzNameInternalBufferUtilStaticCstrName, clazzNameInternalBufferUtilStaticCstrSignature);
(*env)->FatalError(env, clazzNameInternalBufferUtilStaticCstrName);
@@ -130,12 +130,12 @@ static void _initClazzAccess(JNIEnv *env) {
}
/* Java->C glue code:
* Java package: com.sun.nativewindow.impl.x11.X11Lib
* Java method: XVisualInfo XGetVisualInfo(long arg0, long arg1, XVisualInfo arg2, java.nio.IntBuffer arg3)
* C function: XVisualInfo * XGetVisualInfo(Display * , long, XVisualInfo * , int * );
*/
JNIEXPORT jobject JNICALL
-Java_com_sun_nativewindow_impl_x11_X11Lib_XGetVisualInfoCopied1__JJLjava_nio_ByteBuffer_2Ljava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong arg0, jlong arg1, jobject arg2, jobject arg3, jint arg3_byte_offset) {
+Java_com_jogamp_nativewindow_impl_x11_X11Lib_XGetVisualInfoCopied1__JJLjava_nio_ByteBuffer_2Ljava_lang_Object_2I(JNIEnv *env, jclass _unused, jlong arg0, jlong arg1, jobject arg2, jobject arg3, jint arg3_byte_offset) {
XVisualInfo * _ptr2 = NULL;
int * _ptr3 = NULL;
XVisualInfo * _res;
@@ -130,12 +130,12 @@ static void _initClazzAccess(JNIEnv *env) {
}
/* Java->C glue code:
- * Java package: com.sun.nativewindow.impl.x11.X11Lib
+ * Java package: com.jogamp.nativewindow.impl.x11.X11Lib
* Java method: XVisualInfo XGetVisualInfo(long arg0, long arg1, XVisualInfo arg2, java.nio.IntBuffer arg3)
* C function: XVisualInfo * XGetVisualInfo(Display * , long, XVisualInfo * , int * );